@@ -3,7 +3,7 @@ EarthMC is a large Minecraft server this package lets you get info about things
 """
 from __future__ import annotations
 
-__version__ = "v1.3.1"
+__version__ = "v1.5"
 __all__ = [
     "__version__",
     "util",
@@ -15,6 +15,8 @@ __all__ = [
 
 from typing import Dict, Set, Tuple
 
+from shapely.geometry import Polygon
+
 from . import util, exceptions
 
 
@@ -32,6 +34,7 @@ class Nation:
     leader: Resident  #: The leader of the nation
     colour: str  #: The colour that the towns in the nation appear on the map. Standard hex colour code
     citizens: Set[Resident]  #: The citizens of the nation
+    area: int  #: The area of the nation
 
     def __init__(self, name: str, *,
                  data: Tuple[dict, dict] = None):
@@ -50,6 +53,7 @@ class Nation:
         self.colour = self.capital.colour
         self.citizens = {citizen for town in self.towns for citizen in
                          town.residents}
+        self.area = sum(town.area for town in self.towns)
 
     @classmethod
     def all(cls, *, data: Tuple[dict, dict] = None) -> Set[Nation]:
@@ -69,11 +73,12 @@ class Nation:
 
     def __repr__(self) -> str:
         return (
-                "=== {} ===\nTowns: {}\nCapital: {}\nLeader: {}\nColour: {}" +
-                "\nCitizens: {}"
+                "=== {} ===\nTowns: {}\nCapital: {}\nLeader: {}\nColour: {}"
+                "\nCitizens: {}\nArea: {}"
         ).format(self.name, ", ".join([town.name for town in self.towns]),
                  self.capital.name, self.leader.name, self.colour,
-                 ", ".join([citizen.name for citizen in self.citizens]))
+                 ", ".join([citizen.name for citizen in self.citizens]),
+                 self.area)
 
 
 class Town:
@@ -88,8 +93,12 @@ class Town:
     nation: Nation  #: The nation the town is in or None if the town is nationless
     colour: str  #: The colour that the town appears on the map. Standard hex colour code
     mayor: Resident  #: The mayor of the town
-    residents: Set[Resident]  #: The residents of the town
+    residents: List[Resident]  #: The residents of the town
     flags: Dict[str, bool]  #: The flags of the town. pvp, mobs, explosions, fire, capital
+    area: int  #: The area of the town
+    position: Tuple[int, int]  #: The position of the center of the town
+    bounds: util.Bounds  #: The bounds of the town
+    ruins: bool  #: True if this town in ruins, otherwise False
 
     def __init__(self, name: str, *,
                  data: Tuple[dict, dict] = None):
@@ -108,8 +117,8 @@ class Town:
                 self.nation = Nation(nation, data=data)
         self.colour = data[0][name]["fillcolor"]
         self.mayor = Resident._with_town(data[0][name]["desc"][2], data, self)
-        self.residents = {Resident._with_town(person, data, self)
-                          for person in data[0][name]["desc"][4].split(", ")}
+        self.residents = [Resident._with_town(person, data, self)
+                          for person in data[0][name]["desc"][4].split(", ")]
         self.flags = {
             "pvp": data[0][name]["desc"][7] == "pvp: true",
             "mobs": data[0][name]["desc"][8] == "mobs: true",
@@ -117,6 +126,12 @@ class Town:
             "fire": data[0][name]["desc"][11] == "fire: true",
             "capital": data[0][name]["desc"][12] == "capital: true"
         }
+        polygon = Polygon(zip(data[0][name]["x"], data[0][name]["z"]))
+        self.area = int(polygon.area // 256)
+        self.bounds = util.Bounds(*map(int, polygon.bounds))
+        self.position = ((self.bounds.max_x+self.bounds.min_x) // 2, (self.bounds.max_y+self.bounds.min_y) // 2)
+        self.ruins = len(self.residents) == 1 and self.mayor.npc and self.flags == {"pvp": True, "mobs": True, "explosions": True, "fire": True,
+                                                                                    "capital": False}
 
     @classmethod
     def _with_nation(cls, name, data, nation):
@@ -143,12 +158,13 @@ class Town:
 
     def __repr__(self) -> str:
         return (
-                "=== {0} ===\ncolour: {1}\nmayor: {2}\nresidents: {3}\nnation: {4}\n" +
-                "--- flags ---\npvp: {5[pvp]}\nmobs: {5[mobs]}\n" +
+                "=== {0} ===\ncolour: {1}\nmayor: {2}\nresidents: {3}\nnation: {4}\n"
+                "Area: {6}\nPosition: {7}\nBounds: ({8.min_x}-{8.max_x}, {8.min_y}-{8.max_y})\n"
+                "--- flags ---\npvp: {5[pvp]}\nmobs: {5[mobs]}\n"
                 "explosions: {5[explosions]}\nfire: {5[fire]}\ncapital: {5[capital]}"
         ).format(self.name, self.colour, self.mayor.name,
                  ", ".join([person.name for person in self.residents]),
-                 self.nation.name, self.flags)
+                 self.nation.name, self.flags, self.area, self.position, self.bounds)
 
 
 class Resident:
@@ -164,6 +180,7 @@ class Resident:
     hidden: bool  #: Weather or not the resident can be seen on the map
     town: Town  #: The town that the resident belongs to, None if the resident is townless
     nation: Nation  #: The nation that the resident's town is in, None if the resident is townless or the town nationless
+    npc: bool  #: Is this resident an NPC?
 
     def __init__(self, name: str, *, data: Tuple[dict, dict] = None):
         if data is None:
@@ -186,6 +203,7 @@ class Resident:
             self.nation = None
         else:
             self.nation = self.town.nation
+        self.npc = self.name.startswith("NPC") and self.name[3:].isdigit()
 
     @classmethod
     def _with_town(cls, name, data, town):
@@ -225,7 +243,7 @@ class Resident:
 
     def __repr__(self) -> str:
         return (
-                "=== {} ===\nOnline: {}\nPosition: {}\n" +
+                "=== {} ===\nOnline: {}\nPosition: {}\n"
                 "Hidden: {}\nTown: {}\nNation: {}"
         ).format(self.name, self.online, self.position,
                  self.hidden, self.town, self.nation)
